# django-admitad
Приложения для интеграции с Admitad CPA посредством postback-запросов

## Requirements

* [Python 3.7](https://www.python.org/downloads/release/python-370/)
* [Django 2.1.3](https://www.djangoproject.com/)

## Installation
Will be soon...

## Usage
Will be soon...

## TODO
 * Make release
 * Update README.md
 * Write some tests